Learn R Programming

condGEE (version 0.1-4)

condMoments: First and second conditional moments for 3 distributions

Description

K1 provides \(E(Y|Y>w)\) and K2 provides \(E(Y^2|Y>w)\) for Y as standard normal, standardized t with 3 degrees of freedom, or an exponential with mean 0 and variance 1.

Usage

K1.norm(w)
K2.norm(w)
K1.t3(w)
K2.t3(w)
K1.exp(w)
K2.exp(w)

Arguments

w

a real-valued vector

Value

a vector of conditional moments